@@ -23,9 +23,11 @@ from aliyunsdkons.endpoint import endpoint_data
 class OnsRegionListRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Ons', '2019-02-14', 'OnsRegionList')
+		RpcRequest.__init__(self, 'Ons', '2019-02-14', 'OnsRegionList','ons')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
